@@ -2,7 +2,7 @@
 package LWP::Protocol::http::socks;
 require LWP::Protocol::http;
 our @ISA = qw(LWP::Protocol::http);
-our $VERSION = "1.4";
+our $VERSION = "1.6";
 LWP::Protocol::implementor('http::socks' => 'LWP::Protocol::http::socks');
 
 sub new {
@@ -33,7 +33,7 @@ sub configure {
     my $connectAddr = $args->{ConnectAddr} = delete $args->{PeerAddr};
     my $connectPort = $args->{ConnectPort} = delete $args->{PeerPort};
 
-    $self->SUPER::configure($args);
+    $self->SUPER::configure($args) or return;
     $self->http_configure($args);
 }
 
@@ -154,17 +154,20 @@ Then just use your $ua object as usual!
  use LWP::UserAgent;
 
  my $ua = new LWP::UserAgent(agent => 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.5) Gecko/20060719 Firefox/1.5.0.5');
+ # for socks5, use socks like so:
  $ua->proxy([qw(http https)] => 'socks://socks.yahoo.com:1080');
+ # for socks4, use socks4 like so:
+ $ua->proxy([qw(http https)] => 'socks4://socks.yahoo.com:1080');
  my $response = $ua->get("http://www.freebsd.org");
  print $response->code,' ', $response->message,"\n";
  my $response = $ua->get("https://www.microsoft.com");
  print $response->code,' ', $response->message,"\n";
 
-=head1 SEE ALSO
+=head1 NOTES
 
-L<URI::socks>
-
-L<LWP::Protocol::socks4>
+I don't have much time to contribute to this.  If you'd like to
+contribute, please fork https://github.com/scr/cpan and send me a pull
+request.
 
 =head1 AUTHORS
 
